@@ -1,6 +1,6 @@
 matchit.qqplot <- function(x,discrete.cutoff,
                            which.subclass=NULL, numdraws=5000,
-                           interactive = T, which.xs = NULL){
+                           interactive = T, which.xs = NULL,...){
   X <- x$X
   ## Fix X matrix so that it doesn't have any factors
   varnames <- colnames(X)
@@ -54,9 +54,13 @@ matchit.qqplot <- function(x,discrete.cutoff,
   nn <- dimnames(covariates)[[2]]
   nc <- length(nn)
   covariates <- data.matrix(covariates)
-  oma <- c(4, 4, 6, 4)
+ # oma <- c(4, 4, 6, 4)
+  oma <- c(2.25,0,3.75,1.5)
   opar <- par(mfrow = c(3, 3), mar = rep.int(1/2, 4), oma = oma)
   on.exit(par(opar))
+
+ # par(oma=c(2.25,0,3.75,1.5))
+  
   for (i in 1:nc){
     xi <- covariates[,i]
     m.xi <- m.covariates[,i]
@@ -67,28 +71,28 @@ matchit.qqplot <- function(x,discrete.cutoff,
       if(!is.null(which.subclass)){
         htext <- paste(htext,paste(" (Subclass ",which.subclass,")",sep=""),sep="")
       } 
-      mtext(htext, 3, 3, TRUE, 0.5, cex=1.2,font=2)
-      mtext("All", 3, 1, TRUE, 0.5, cex=1.2,font = 1)
-      mtext("Matched", 3, 1, TRUE, 0.83, cex=1.2,font = 1)
+      mtext(htext, 3, 2, TRUE, 0.5, cex=1.1,font=2)
+      mtext("All", 3, .25, TRUE, 0.5, cex=1,font = 1)
+      mtext("Matched", 3, .25, TRUE, 0.83, cex=1,font = 1)
       mtext("Control Units", 1, 0, TRUE, 2/3, cex=1,font = 1)
       mtext("Treated Units", 4, 0, TRUE, 0.5, cex=1,font = 1)
     }
     par(usr = c(0, 1, 0, 1))
     l.wid <- strwidth(nn, "user")
-    cex.labels <- max(0.8, min(2, 0.9/max(l.wid)))
+    cex.labels <- max(0.75, min(1.45, 0.85/max(l.wid)))
     text(0.5,0.5,ni,cex=cex.labels)
     if(length(table(xi))<=discrete.cutoff){
       xi <- jitter(xi)
       m.xi <- jitter(m.xi)
     }
     rr <- range(xi)
-    eqqplot(xi[treat==0],xi[treat==1], xlim=rr,ylim=rr,axes=F,ylab="",xlab="")
+    eqqplot(xi[treat==0],xi[treat==1], xlim=rr,ylim=rr,axes=F,ylab="",xlab="",...)
     abline(a=0,b=1)
     abline(a=(rr[2]-rr[1])*0.1,b=1,lty=2)
     abline(a=-(rr[2]-rr[1])*0.1,b=1,lty=2)
     axis(2)
     box()
-    eqqplot(m.xi[m.treat==0],m.xi[m.treat==1],xlim=rr,ylim=rr,axes=F,ylab="",xlab="")
+    eqqplot(m.xi[m.treat==0],m.xi[m.treat==1],xlim=rr,ylim=rr,axes=F,ylab="",xlab="",...)
     abline(a=0,b=1)
     abline(a=(rr[2]-rr[1])*0.1,b=1,lty=2)
     abline(a=-(rr[2]-rr[1])*0.1,b=1,lty=2)
